==> influxobject-0.0.1.tar.gz: influxobject-0.0.1/setup.py <==
import setuptools

with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name='influxobject',
    author='John Doe',
    author_email='john.doe@gmail.com',
    description='Influx Object Package',
    keywords='influx, json, package',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://gitlab.com/m-unlock/influx-object',
    project_urls={
        'Documentation': 'https://gitlab.com/m-unlock/influx-object',
        'Bug Reports':
        'https://gitlab.com/m-unlock/influx-object/-/issues',
        'Source Code': 'https://gitlab.com/m-unlock/influx-object',
        # 'Funding': '',
        # 'Say Thanks!': '',
    },
    package_dir={'': 'src'},
    packages=setuptools.find_packages(where='src'),
    classifiers=[
        # see https://pypi.org/classifiers/
        'Development Status :: 4 - Beta',

        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # 'Programming Language :: Python :: 3',
        # 'Programming Language :: Python :: 3.6',
        # 'Programming Language :: Python :: 3.7',
        # 'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3 :: Only',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    # install_requires=['Pillow'],
    extras_require={
        'dev': ['check-manifest'],
        # 'test': ['coverage'],
    },
    # entry_points={
    #     'console_scripts': [  # This can provide executable scripts
    #         'run=examplepy:main',
    # You can execute `run` in bash to run `main()` in src/examplepy/__init__.py
    #     ],
    # },
)

==> influxobject-0.0.3.tar.gz: influxobject-0.0.3/setup.py <==
import setuptools

with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name='influxobject',
    author='Jasper Koehorst, Brett Metcalfe',
    author_email='jasper.koehorst@wur.nl',
    description='Influx Object Package',
    keywords='influx, json, package',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://gitlab.com/m-unlock/influx-object',
    project_urls={
        'Documentation': 'https://gitlab.com/m-unlock/influx-object',
        'Bug Reports':
        'https://gitlab.com/m-unlock/influx-object/-/issues',
        'Source Code': 'https://gitlab.com/m-unlock/influx-object',
        # 'Funding': '',
        # 'Say Thanks!': '',
    },
    package_dir={'': 'src'},
    packages=setuptools.find_packages(where='src'),
    classifiers=[
        # see https://pypi.org/classifiers/
        'Development Status :: 4 - Beta',

        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # 'Programming Language :: Python :: 3',
        # 'Programming Language :: Python :: 3.6',
        # 'Programming Language :: Python :: 3.7',
        # 'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3 :: Only',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    # install_requires=['Pillow'],
    extras_require={
        'dev': ['check-manifest'],
        # 'test': ['coverage'],
    },
    # entry_points={
    #     'console_scripts': [  # This can provide executable scripts
    #         'run=examplepy:main',
    # You can execute `run` in bash to run `main()` in src/examplepy/__init__.py
    #     ],
    # },
)
